@@ -37,11 +37,10 @@ typedef tReal tGen;
 
 
 #ifndef _TFITNESS
-typedef long double tFitness;
+typedef double tFitness;
 #define _TFITNESS 1
 #endif 
 
-
 namespace realea {
 
 typedef vector<tReal> tChromosomeReal;
